@@ -5,8 +5,10 @@ import enum
 import typing
 
 import jsii
-import jsii.compat
 import publication
+import typing_extensions
+
+from typeguard import check_type
 
 import aws_cdk.aws_dynamodb._jsii
 import aws_cdk.aws_ec2._jsii
@@ -20,7 +22,7 @@ import aws_cdk.core._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
-    "@aws-cdk/aws-backup", "1.62.0", __name__[0:-6], "aws-backup@1.62.0.jsii.tgz"
+    "@aws-cdk/aws-backup", "1.174.0", __name__[0:-6], "aws-backup@1.174.0.jsii.tgz"
 )
 
 __all__ = [
